package com.hungraim.ltc.governance.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.AprOrganService;
import com.hungraim.ltc.pojo.vo.governance.AprOrganVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 评定机构及评定机构人员信息管理Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/organ")
@Slf4j
public class AprOrganController {

    @Autowired
    private AprOrganService aprOrganService;

    /**
     * 评定机构信息列表
     *
     * @param pageNum    页码
     * @param pageSize   每页展示条数
     * @param organId    适用机构id
     * @param isIncluded 是否包含下级机构,值为true，则包含organId的下层机构
     * @param organName  机构名称
     * @param code       统一社会信用代码
     */
    @RequestMapping("/aprOrganList")
    public Result<Page<AprOrganVO>> aprOrganList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                 Long organId, Boolean isIncluded, String organName, String code) {
        Page<AprOrganVO> page = new Page<>(pageNum, pageSize);
        page = aprOrganService.aprOrganList(page, organId, isIncluded, organName, code);
        return Result.success(page);
    }

    /**
     * 更改评定机构状态
     *
     * @param aprOrganId 监管机构id
     * @param status     状态 有效：0；失效：1
     */
    @DeleteMapping("/updateAprOrganStatus")
    public Result updateSpvStatus(String aprOrganId, Short status) {
        if (StringUtils.isBlank(aprOrganId) || status == null || (status != 1 && status != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        aprOrganService.updateAprOrganStatus(aprOrganId, status);
        return Result.success();
    }

}
