package com.hungraim.ltc.governance.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.OrganFeignService;
import com.hungraim.ltc.governance.dao.SuperviseOrganEmpMapper;
import com.hungraim.ltc.governance.dao.SuperviseOrganMapper;
import com.hungraim.ltc.governance.service.SuperviseOrganEmpService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrgan;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrganEmp;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganEmpVO;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganVO;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 监管机构人员信息管理ServiceImpl
 */
@Service
@Slf4j
@AllArgsConstructor
public class SuperviseOrganServiceImpl implements SuperviseOrganEmpService {
    private final SuperviseOrganEmpMapper superviseOrganEmpMapper;
    private final SuperviseOrganMapper superviseOrganMapper;
    private final OrganFeignService organFeignService;

    @Override
    public Page<SuperviseOrganEmpVO> superviseOrganEmpList(Page<SuperviseOrganEmpVO> page, Long organId, Boolean isIncluded, String organName, String superviseType, String superviseName, String superviseTel, String status) {
        return superviseOrganEmpMapper.superviseOrganEmpList(page, getOrganIds(organId, isIncluded), organName, superviseType, superviseName, superviseTel, status);
    }

    private List<Long> getOrganIds(Long organId, Boolean isIncluded) {
        Result<List<Long>> organChild = null;
        List<Long> organIds = null;
        if (organId != null) {
            if (isIncluded == null) {
                isIncluded = false;
            }
            organChild = organFeignService.getOrganChild(organId, isIncluded);
            return organChild.getData();
        }
        return null;
    }

    @Override
    public void updateEmpStatus(String empId, Short isLock) {
        ChSuperviseOrganEmp chSuperviseOrganEmp = superviseOrganEmpMapper.selectById(empId);
        chSuperviseOrganEmp.setIsLock(isLock);
        superviseOrganEmpMapper.updateById(chSuperviseOrganEmp);
    }

    @Override
    public void insertOrUpdateEmpInfo(Long empId, Long spvOrganId, String spvEmpName, String certifType, String certifNum, String gender, Short age, String superviseTel, Short status) {
        if (empId != null) {
            //更新
            ChSuperviseOrganEmp chSuperviseOrganEmp = superviseOrganEmpMapper.selectById(empId);
            chSuperviseOrganEmp.setSpvOrganId(spvOrganId);
            chSuperviseOrganEmp.setSpvEmpName(spvEmpName);
            chSuperviseOrganEmp.setCertifType(certifType);
            chSuperviseOrganEmp.setCertifNum(certifNum);
            chSuperviseOrganEmp.setGender(gender);
            chSuperviseOrganEmp.setAge(age);
            chSuperviseOrganEmp.setMobilePhone(superviseTel);
            chSuperviseOrganEmp.setIsLock(status);
            superviseOrganEmpMapper.updateById(chSuperviseOrganEmp);
        } else {
            //新增
            ChSuperviseOrganEmp chSuperviseOrganEmp = new ChSuperviseOrganEmp();
            chSuperviseOrganEmp.setEffTime(new Date());
            chSuperviseOrganEmp.setSpvOrganId(spvOrganId);
            chSuperviseOrganEmp.setSpvEmpName(spvEmpName);
            chSuperviseOrganEmp.setCertifType(certifType);
            chSuperviseOrganEmp.setCertifNum(certifNum);
            chSuperviseOrganEmp.setGender(gender);
            chSuperviseOrganEmp.setAge(age);
            chSuperviseOrganEmp.setMobilePhone(superviseTel);
            chSuperviseOrganEmp.setIsLock(status);
            superviseOrganEmpMapper.insert(chSuperviseOrganEmp);
        }
    }

    @Override
    public Page<SuperviseOrganVO> superviseOrganList(Page<SuperviseOrganVO> page, Long organId, Boolean isIncluded, String spvOrganName) {
        return superviseOrganMapper.superviseOrganList(page, getOrganIds(organId, isIncluded), spvOrganName);
    }

    @Override
    public void updateSpvStatus(String spvOrganId, Short isLock) {
        ChSuperviseOrgan chSuperviseOrgan = superviseOrganMapper.selectById(spvOrganId);
        chSuperviseOrgan.setIsLock(isLock);
        superviseOrganMapper.updateById(chSuperviseOrgan);
    }

    @Override
    public void insertOrUpdateSpvInfo(ChSuperviseOrgan spvOrgan) {
        if (spvOrgan.getSpvOrganId() != null) {
            //更新
            ChSuperviseOrgan chSuperviseOrgan = superviseOrganMapper.selectById(spvOrgan);
            chSuperviseOrgan.setOrganId(spvOrgan.getOrganId());
            chSuperviseOrgan.setDistrictProvince(spvOrgan.getDistrictProvince());
            chSuperviseOrgan.setDistrictCity(spvOrgan.getDistrictCity());
            chSuperviseOrgan.setDistrictArea(spvOrgan.getDistrictArea());
            chSuperviseOrgan.setSpvOrganName(spvOrgan.getSpvOrganName());
            chSuperviseOrgan.setContactTel(spvOrgan.getContactTel());
            superviseOrganMapper.updateById(spvOrgan);
        } else {
            //新增
            spvOrgan.setIsLock((short) 0);
            spvOrgan.setEffTime(new Date());
            superviseOrganMapper.insert(spvOrgan);
        }
    }
}
